# Abstractions for **AIMedic**'s training pipeline
Abstractions for main components in *AIMedic*'s ``tensorflow``-based projects.

# Guide
[Plz don't be lazy and `readthedocs`! :)](https://abstractions.readthedocs.io/en/latest/)